@@ -139,6 +139,32 @@ to_sql.relop_null_replace <- function (x,
                                        tnum = mk_tmp_name_source('tsql'),
                                        append_cr = TRUE,
                                        using = NULL) {
+  if(length(list(...))>0) {
+    stop("rquery::to_sql.relop_null_replace unexpected arguments")
+  }
+  dispatch_to_sql_method(
+    method_name = "to_sql.relop_null_replace",
+    x = x,
+    db = db,
+    limit = limit,
+    source_limit = source_limit,
+    indent_level = indent_level,
+    tnum = tnum,
+    append_cr = append_cr,
+    using = using)
+}
+
+
+to_sql_relop_null_replace <- function(
+  x,
+  db,
+  ...,
+  limit = NULL,
+  source_limit = NULL,
+  indent_level = 0,
+  tnum = mk_tmp_name_source('tsql'),
+  append_cr = TRUE,
+  using = NULL) {
   if(length(list(...))>0) {
     stop("unexpected arguments")
   }
@@ -206,3 +232,4 @@ to_sql.relop_null_replace <- function (x,
   c(subsqla_list[-length(subsqla_list)],
     q)
 }
+
