@@ -263,6 +263,32 @@ to_sql.relop_project <- function (x,
                                   tnum = mk_tmp_name_source('tsql'),
                                   append_cr = TRUE,
                                   using = NULL) {
+  if(length(list(...))>0) {
+    stop("rquery::to_sql.relop_project unexpected arguments")
+  }
+  dispatch_to_sql_method(
+    method_name = "to_sql.relop_project",
+    x = x,
+    db = db,
+    limit = limit,
+    source_limit = source_limit,
+    indent_level = indent_level,
+    tnum = tnum,
+    append_cr = append_cr,
+    using = using)
+}
+
+
+to_sql_relop_project <- function(
+  x,
+  db,
+  ...,
+  limit = NULL,
+  source_limit = NULL,
+  indent_level = 0,
+  tnum = mk_tmp_name_source('tsql'),
+  append_cr = TRUE,
+  using = NULL) {
   if(length(list(...))>0) {
     stop("unexpected arguments")
   }
@@ -279,7 +305,7 @@ to_sql.relop_project <- function (x,
   re_assignments <- unpack_assignments(x$source[[1]], re_quoted)
   # work on query
   using_incoming <- calc_used_relop_project(x,
-                                   using = using)
+                                            using = using)
   subsql_list <- to_sql(x$source[[1]],
                         db = db,
                         source_limit = source_limit,
@@ -335,3 +361,4 @@ to_sql.relop_project <- function (x,
   }
   c(subsql_list[-length(subsql_list)], q)
 }
+
